==> liblxqt-0.15.1.tar.xz: liblxqt-0.15.1/translations/liblxqt_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Fout van LXQt-Energiebeheerder</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Slaapstand is mislukt.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Reserve-meldingensysteem</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt-Sessie-pauzestand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Wilt u uw computer echt in pauzestand brengen?&lt;p&gt;Pauzestand brengt de computer in een energiespaarstand. De systeemstatus blijft niet behouden wanneer de stroomtoevoer wordt verbroken.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt-Sessie-slaapstand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Wilt u uw computer echt in slaapstand brengen?&lt;p&gt;Slaapstand brengt de computer in een energiespaarstand. De systeemstatus blijft behouden wanneer de stroomtoevoer wordt verbroken.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt-Sessie-herstarten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Wilt u uw computer echt herstarten? Al uw niet-opgeslagen werk zal verloren gaan...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt-Sessie-afsluiten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Wilt u uw computer echt afsluiten? Al uw niet-opgeslagen werk zal verloren gaan...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Meld LXQt-sessie af</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Wilt u zich echt afmelden? Al uw niet-opgeslagen werk zal verloren gaan...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Fout van LXQt-energiebeheerder</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Slaapstand is mislukt.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Pauzestand is mislukt.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Mislukt om  &quot;%1&quot; te runnen. Controleer of je een schermbeveiliging hebt die compatibel is met de geïnstalleerde en runnende xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Mislukt om  &quot;%1&quot; te runnen. Controleer of de aangegeven schermbeveiliging is geïnstalleerd en runt.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Vergrendel scherm</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Fout van schermbeveiliging</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Kies de weer te geven bladzijde.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Fout van energiebeheerder</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface is ongeldig</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Fout van energiebeheerder (D-BUS-oproep)</translation>
    </message>
</context>
</TS>

==> liblxqt-1.0.0.tar.xz: liblxqt-1.0.0/translations/liblxqt_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoogvenster</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Foutmelding van LXQt-energiebeheer</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Slaapstand is mislukt.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Reserve-meldingensysteem</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt-pauzestand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Weet u zeker dat u uw computer in de pauzestand wilt zetten?&lt;p&gt;De pauzestand zet de computer in een energiespaarstand. Geopende programma&apos;s en bestanden worden niet bewaard als de stroomtoevoer wordt onderbroken.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt-slaapstand</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Weet u zeker dat u uw computer in de slaapstand wilt zetten?&lt;p&gt;De slaapstand zet de computer in een energiespaarstand. Geopende programma&apos;s en bestanden worden bewaard als de stroomtoevoer wordt onderbroken.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt herstarten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Weet u zeker dat u uw computer wilt herstarten? Al uw onopgeslagen werk wordt niet bewaard…</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt afsluiten</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Weet u zeker dat u uw computer wilt afsluiten? Al uw onopgeslagen werk wordt niet bewaard…</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt afmelden</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Weet u zeker dat u wilt afmelden? Al uw onopgeslagen werk wordt niet bewaard…</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Foutmelding van LXQt-energiebeheer</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Slaapstand is mislukt.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Pauzestand is mislukt.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>&apos;%1&apos; kan niet worden uitgevoerd. Zorg dat u over een schermbeveiliging beschikt die compatibel is met xdg-screensaver en dat deze actief is.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>&apos;%1&quot; kan niet worden uitgevoerd. Zorg dat de opgegeven schermbeveiliging geïnstalleerd en actief is.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Scherm vergrendelen</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Schermbeveiligingsfout</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Kies de te tonen pagina.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Energiebeheerfout</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface is ongeldig</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Energiebeheerfout (D-BUS-aanroep)</translation>
    </message>
</context>
</TS>
